# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

<!--
   PRs should document their user-visible changes (if any) in the
   Unreleased section, uncommenting the header as necessary.
-->

<!-- ## Unreleased -->
<!-- ### Changed -->
<!-- ### Added -->
<!-- ### Removed -->
<!-- ### Fixed -->


## [2.0.0rc1 - 2019-04-13]
### Changed
* require Elasticsearch 6.x
* move data structure to single document per index 
* got rid of bower and moved to npm in build process
* updated angular packages to new versions

## [1.2.0 - 2019-03-17]
### Changed
* Replaced elasticsearch client
* Bumped a most deps to latest version
* Preparing to move from elasticsearch 2.x to modern versions
